NetToChainAdapter

Struct NetToChainAdapter 

pub struct NetToChainAdapter<B, P>
where B: BlockChain, P: PoolAdapter,
{ /* private fields */ }
Implementation of the NetAdapter for the . Gets notified when new blocks and transactions are received and forwards to the chain and pool implementations.

Implementations

Source

impl<B, P> NetToChainAdapter<B, P>
where B: BlockChain, P: PoolAdapter,

pub fn new( sync_state: Arc<SyncState>, chain: Arc<Chain>, tx_pool: Arc<RwLock<TransactionPool<B, P>>>, config: ServerConfig, hooks: Vec<Box<dyn NetEvents + Send + Sync>>, ) -> Self

Construct a new NetToChainAdapter instance

pub fn init(&self, peers: Arc<Peers>)

Initialize a NetToChainAdaptor with reference to a Peers object. Should only be called once.