pub struct NetToChainAdapter<B, P>where
B: BlockChain,
P: PoolAdapter,{ /* private fields */ }Expand description
Implementation of the NetAdapter for the . Gets notified when new blocks and transactions are received and forwards to the chain and pool implementations.
Implementations
Sourceimpl<B, P> NetToChainAdapter<B, P>where
B: BlockChain,
P: PoolAdapter,
impl<B, P> NetToChainAdapter<B, P>where
B: BlockChain,
P: PoolAdapter,